@@ -1,6 +1,6 @@
 /* -*- mode: C; mode: fold -*- */
 /*
-Copyright (C) 2013-2021,2022 John E. Davis, Manfred Hanke
+Copyright (C) 2013 John E. Davis, Manfred Hanke
 
 This file is part of the S-Lang Library.
 
@@ -20,8 +20,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 USA.
 */
 
-#define _BSD_SOURCE 1		       /* to get strtoll */
-#define _DEFAULT_SOURCE 1
 #include "config.h"
 
 #include <stdlib.h>
@@ -164,12 +162,13 @@ static int parse_string_length_and_move_ptr (Parse_Type *p, unsigned int *lenp,
 {
    unsigned int new_string_len = 0;
    char *s = p->ptr;
+   char ch;
 
    *lenp = 0; *is_binary_stringp = 0;
 
    while (1)
      {
-	char ch = *s++;
+	ch = *s++;
 
 	/* STRING_DELIMITER = 34, SPACE = 32 */
 	if ((unsigned char)ch <= STRING_DELIMITER)
@@ -558,7 +557,7 @@ static void free_string_array (char **sp, unsigned int n)
    SLfree ((char *)sp);
 }
 
-/* This hash table implementation does not copy the strings */
+/* This has table implementation does not copy the strings */
 #define HASH_TABLE_SIZE 601
 typedef struct String_Hash_Elem_Type
 {
@@ -663,7 +662,7 @@ static int parse_and_push_object_as_struct (Parse_Type *p, int toplevel) /*{{{*/
    char buf[512];
    unsigned int num_fields, max_fields;
    char **fields;
-   String_Hash_Type *h = NULL;
+   String_Hash_Type *h;
 
    max_fields = 16;
    num_fields = 0;
@@ -786,9 +785,6 @@ static int parse_and_push_array (Parse_Type *p, int toplevel) /*{{{*/
 {
    SLang_List_Type *list = SLang_create_list (8);   /* let's start with 8 elements */
 
-   if (list == NULL)
-     return -1;
-
    skip_white (p);
    if (! looking_at (p, END_ARRAY)) do
      {
@@ -895,61 +891,14 @@ static char *String_Map[128] = /*{{{*/
 };
 /*}}}*/
 
-/* Adapted from SLutf8.c */
-static int is_invalid_or_overlong_utf8 (SLuchar_Type *u, unsigned int len)
+static SLstrlen_Type compute_multibyte_char_len (unsigned char ch) /*{{{*/
 {
-   unsigned int i;
-   unsigned char ch, ch1;
-
-   /* Check for invalid sequences */
-   for (i = 1; i < len; i++)
-     {
-	if ((u[i] & 0xC0) != 0x80)
-	  return 1;
-     }
-
-   /* Illegal (overlong) sequences */
-   /*           1100000x (10xxxxxx) */
-   /*           11100000 100xxxxx (10xxxxxx) */
-   /*           11110000 1000xxxx (10xxxxxx 10xxxxxx) */
-   /*           11111000 10000xxx (10xxxxxx 10xxxxxx 10xxxxxx) */
-   /*           11111100 100000xx (10xxxxxx 10xxxxxx 10xxxxxx 10xxxxxx) */
-   ch = *u;
-   if ((ch == 0xC0) || (ch == 0xC1))
-     return 1;
-
-   ch1 = u[1];
-   if (((ch1 & ch) == 0x80)
-       && ((ch == 0xE0)
-	   || (ch == 0xF0)
-	   || (ch == 0xF8)
-	   || (ch == 0xFC)))
-     return 1;
-
-   return 0;
+   return ((ch & 0xE0) == 0xC0) ? 2  /* (ch & 0b11100000) == 0b11000000 */
+        : ((ch & 0xF0) == 0xE0) ? 3  /* (ch & 0b11110000) == 0b11100000 */
+        : ((ch & 0xF8) == 0xF0) ? 4  /* (ch & 0b11111000) == 0b11110000 */
+        : ((ch & 0xFC) == 0xF8) ? 5  /* (ch & 0b11111100) == 0b11111000 */
+        :                         6;
 }
-
-static SLstrlen_Type compute_multibyte_char_len (char *p, char *pmax) /*{{{*/
-{
-   SLstrlen_Type len;
-   unsigned char ch;
-
-   ch = (unsigned char)*p;
-   len = ((ch & 0xE0) == 0xC0) ? 2  /* (ch & 0b11100000) == 0b11000000 */
-     : ((ch & 0xF0) == 0xE0) ? 3  /* (ch & 0b11110000) == 0b11100000 */
-     : ((ch & 0xF8) == 0xF0) ? 4  /* (ch & 0b11111000) == 0b11110000 */
-     : ((ch & 0xFC) == 0xF8) ? 5  /* (ch & 0b11111100) == 0b11111000 */
-     :                         6;
-
-   if (p + len > pmax)
-     return 1;
-
-   if (is_invalid_or_overlong_utf8 ((SLuchar_Type *)p, len))
-     return 1;
-
-   return len;
-}
-
 /*}}}*/
 
 static char *alloc_encoded_json_string (char *ptr, char *end_of_input_string, SLstrlen_Type *lenp) /*{{{*/
@@ -966,9 +915,8 @@ static char *alloc_encoded_json_string (char *ptr, char *end_of_input_string, SL
 	     continue;
 	  }
 
-	len += 6;		       /* FIXME: Does not handle 0x1UUUU */
-	ptr += compute_multibyte_char_len (ptr, end_of_input_string);
-
+	len += 6;
+	ptr += compute_multibyte_char_len (ch);
 	if (ptr > end_of_input_string)
 	  {
 	     SLang_verror (Json_Invalid_Json_Error, "Invalid UTF-8 at end of string");
@@ -981,8 +929,7 @@ static char *alloc_encoded_json_string (char *ptr, char *end_of_input_string, SL
 }
 /*}}}*/
 
-static char *fill_encoded_json_string (char *ptr, char *end_of_input_string,
-				       char *dest_ptr) /*{{{*/
+static void fill_encoded_json_string (char *ptr, char *end_of_input_string, char *dest_ptr) /*{{{*/
 {
    *dest_ptr++ = STRING_DELIMITER;
 
@@ -1006,14 +953,7 @@ static char *fill_encoded_json_string (char *ptr, char *end_of_input_string,
 	  }
 
 	/* We cannot use SLutf8_decode, since we need to handle invalid_or_overlong_utf8 or ILLEGAL_UNICODE as well. */
-	len = compute_multibyte_char_len (ptr, end_of_input_string);
-	if (len == 1)
-	  {
-	     /* Malformed or overlong */
-	     sprintf (dest_ptr, "<%02X>", (unsigned char)*ptr);
-	     dest_ptr += 4;
-	  }
-	else
+	len = compute_multibyte_char_len (ch);
 	  {  /* stolen from slutf8.c : fast_utf8_decode */
 	     static unsigned char masks[7] = { 0, 0, 0x1F, 0xF, 0x7, 0x3, 0x1 };
 	     SLwchar_Type w = (ch & masks[len]);
@@ -1021,23 +961,13 @@ static char *fill_encoded_json_string (char *ptr, char *end_of_input_string,
 	     for (i = 1; i < len; i++)
 	       w = (w << 6) | (ptr[i] & 0x3F);
 
-	     if (w > 0xFFFF)
-	       {
-		  /* FIXME: Must be encoded as a pair of UTF-16 surrogates */
-		  memcpy (dest_ptr, ptr, len);
-		  dest_ptr += len;
-	       }
-	     else
-	       {
-		  sprintf (dest_ptr, "\\u%04X", w);
-		  dest_ptr += 6;
-	       }
+	     sprintf (dest_ptr, "\\u%04X", w);
+	     dest_ptr += 6;
 	  }
 	ptr += len;
      }
    *dest_ptr++ = STRING_DELIMITER;
    *dest_ptr = 0;
-   return dest_ptr;
 }
 /*}}}*/
 
@@ -1067,10 +997,8 @@ static void json_encode_string (void) /*{{{*/
    if ((encoded_json_string = alloc_encoded_json_string (string, string + len, &new_len)) != NULL)
      {
 	SLang_BString_Type *b;
-	char *enc_end;
 
-	enc_end = fill_encoded_json_string (string, string + len, encoded_json_string);
-	new_len = enc_end - encoded_json_string;
+	fill_encoded_json_string (string, string + len, encoded_json_string);
 
 	b = SLbstring_create_malloced ((unsigned char *)encoded_json_string, new_len, 1);
 	if (b != NULL)
