@@ -1,6 +1,6 @@
 /* Basic type operations for S-Lang */
 /*
-Copyright (C) 2004-2021,2022 John E. Davis
+Copyright (C) 2004-2014 John E. Davis
 
 This file is part of the S-Lang Library.
 
@@ -598,8 +598,8 @@ static int ref_push (SLtype type, VOID_STAR ptr)
 
 int SLang_assign_to_ref (SLang_Ref_Type *ref, SLtype type, VOID_STAR v)
 {
+   SLang_Object_Type *stkptr;
    SLang_Class_Type *cl;
-   int stack_depth;
 
    cl = _pSLclass_get_class (type);
 
@@ -623,11 +623,11 @@ int SLang_assign_to_ref (SLang_Ref_Type *ref, SLtype type, VOID_STAR v)
    if (-1 == (*cl->cl_apush) (type, v))
      return -1;
 
-   stack_depth = SLstack_depth ();
+   stkptr = _pSLang_get_run_stack_pointer ();
    if (0 == _pSLang_deref_assign (ref))
      return 0;
 
-   if (stack_depth != SLstack_depth ())
+   if (stkptr != _pSLang_get_run_stack_pointer ())
      SLdo_pop ();
 
    return -1;
@@ -950,22 +950,6 @@ static int intp_pop (SLtype unused, VOID_STAR ptr)
    return SLang_pop_integer (addr);
 }
 
-int _pSLang_pop_wchar (SLwchar_Type *wcp)
-{
-   /* FIXME: This bit of code will be merged into the SLang_pop_wchar function
-    * for the next major version.  Currently, SLang_pop_wchar is a macro.
-    */
-   if (SLang_peek_at_stack () == SLANG_CHAR_TYPE)
-     {
-	char ch;
-	if (-1 == SLang_pop_char (&ch))
-	  return -1;
-	*wcp = (unsigned char)ch;
-	return 0;
-     }
-   return SLang_pop_wchar (wcp);
-}
-
 static int undefined_method (SLtype t, VOID_STAR p)
 {
    (void) t; (void) p;
@@ -977,30 +961,21 @@ static void void_undefined_method (SLtype t, VOID_STAR p)
    (void) t; (void) p;
 }
 
-static void check_sizeof (size_t c, size_t s, const char *obj, int *errp)
-{
-   if (c == s) return;
-   (void) fprintf (stderr, "C sizeof (%s) is %d, configured to be %d\n",
-		   obj, (int)c, (int)s);
-   *errp = 1;
-}
-
 int _pSLregister_types (void)
 {
    SLang_Class_Type *cl;
-   int err = 0;
 
-   check_sizeof (sizeof(short), SIZEOF_SHORT, "short", &err);
-   check_sizeof (sizeof(int), SIZEOF_INT, "int", &err);
-   check_sizeof (sizeof(long), SIZEOF_LONG, "long", &err);
-   check_sizeof (sizeof(float), SIZEOF_FLOAT, "float", &err);
-   check_sizeof (sizeof(double), SIZEOF_DOUBLE, "double", &err);
-   check_sizeof (sizeof(size_t), SIZEOF_SIZE_T, "size_t", &err);
-   check_sizeof (sizeof(off_t), SIZEOF_OFF_T, "off_t", &err);
-
-   if (err)
+#if 1
+   /* A good compiler should optimize this code away. */
+   if ((sizeof(short) != SIZEOF_SHORT)
+       || (sizeof(int) != SIZEOF_INT)
+       || (sizeof(long) != SIZEOF_LONG)
+       || (sizeof(float) != SIZEOF_FLOAT)
+       || (sizeof(double) != SIZEOF_DOUBLE)
+       || (sizeof(size_t) != SIZEOF_SIZE_T)
+       || (sizeof(off_t) != SIZEOF_OFF_T))
      SLang_exit_error ("S-Lang Library not built properly.  Fix SIZEOF_* in config.h and recompile");
-
+#endif
    if (-1 == _pSLclass_init ())
      return -1;
 
